Enum muse_lang::compiler::Error

source ·
pub enum Error {
Show 15 variants VariableNotMutable, TooManyArguments, UsizeTooLarge, PublicFunctionRequiresName, StructFunctionRequiresName, InvalidLabel, PubOnlyInModules, ExpectedBlock, NameAlreadyBound, UnknownSigil, OrPatternBindingsMismatch, ElseOnIrrefutablePattern, LetElseMustDiverge, Syntax(ParseError), SigilSyntax(ParseError),
}
A compilation error.

Variants



VariableNotMutable

A variable cannot be assigned to if it is not mutable.



TooManyArguments

Too many arguments were provided to a function call. The maximum number of arguments to a function is 255.



UsizeTooLarge

A usize was too large to convert into a smaller integer type. In general, this should not ever be returned given that other limits will likely be reached before this could be.



PublicFunctionRequiresName

A public function requires a name.



StructFunctionRequiresName

A function in a structure requires a name.



InvalidLabel

A label is not valid.



PubOnlyInModules

Public declarations can only exist within a module’s scope.



ExpectedBlock

Expected a block/



NameAlreadyBound

This name is already bound in the current pattern match.



UnknownSigil

This sigil is not known to the compiler.



OrPatternBindingsMismatch

All pattern options must contain the same name bindings.



ElseOnIrrefutablePattern

Else was provided on an irrefutable pattern.



LetElseMustDiverge

The else expression in a let..else expression must diverge.



Syntax(ParseError)

A syntax error occurred.



SigilSyntax(ParseError)

A syntax error occurred while parsing an expanded macro.