pub enum UnaryKind {
Truthy,
LogicalNot,
BitwiseNot,
Negate,
Copy,
Resolve,
Jump,
SetExceptionHandler,
}Expand description
An operation that is performed on a single argument.
Variants
Truthy
Evaluates the argument’s truthyness
LogicalNot
not op
BitwiseNot
!op
Negate
-op
Copy
Copies the argument.
Resolve
Resolves a name in the current scope.
Jump
Jumps to the instruction address. The destination will contain the current address before jumping.
SetExceptionHandler
Sets the exception handler to the label provided. The destination will contain the overwritten exception handler.