Enum muse_lang::compiler::syntax::EntryKeyPattern
source · pub enum EntryKeyPattern {
Nil,
Bool(bool),
Int(i64),
UInt(u64),
Float(f64),
String(Symbol),
Identifier(Symbol),
}Expand description
The syntax components of the key portion of a pattern match on a map field.
Variants
Nil
Match if nil
Bool(bool)
Match if a boolean of a given value.
Int(i64)
Match if an integer of a given value.
While this pattern is unsigned, if an unsigned integer has the same numerical value, it will still match.
UInt(u64)
Match if an integer of a given value.
While this pattern is unsigned, if a signed integer has the same numerical value, it will still match.
Float(f64)
Match if a float of a given value.
Float matching checks if the difference between the pattern and value is
less than f64::EPSILON.
String(Symbol)
Match if a string of a given value.
Identifier(Symbol)
Match against a value contained in a variable.