pub enum LoopKind {
Infinite,
While(Ranged<Expression>),
TailWhile {
while: Ranged<Token>,
expression: Ranged<Expression>,
},
For {
pattern: Ranged<Pattern>,
in: Ranged<Token>,
source: Ranged<Expression>,
},
}Expand description
The kind of a loop expression.
Variants
Infinite
A loop that repeats forever with no conditions.
While(Ranged<Expression>)
A loop that checks the expression each time before the body executes.
TailWhile
A loop that checks the expression each time after the body executes.
Fields

expression: Ranged<Expression>The expression to check.
For
A loop over an iterable or indexable.