Enum muse_lang::compiler::syntax::ParseError

source ·
pub enum ParseError {
Show 27 variants UnexpectedEof, ExpectedEof, MissingEnd(Paired), MissingEndOr(Paired, char), Token(LexerError), UnexpectedToken, ExpectedDeclaration, ExpectedName, ExpectedStructureMember, ExpectedBlock, ExpectedModuleBody, ExpectedFunctionBody, ExpectedEnumBody, ExpectedEnumVariant, ExpectedIn, ExpectedFunctionParameters, ExpectedThenOrBrace, ExpectedColon, ExpectedCommaOrBrace, ExpectedMatchBody, ExpectedPattern, ExpectedPatternOr(Paired), ExpectedFatArrow, ExpectedCatchBlock, InvalidAssignmentTarget, InvalidLabelTarget, InvalidMapKeyPattern,
}
A syntax parsing error.

Variants



UnexpectedEof

An unexpected end of file.



ExpectedEof

Expected the end of a file.



MissingEnd(Paired)

Missing the end of a paired token.



MissingEndOr(Paired, char)

Missing the end of a paired token.



Token(LexerError)

An error tokenizing the source code.



UnexpectedToken

An unexpectecd token was encountered in the given context.



ExpectedDeclaration

Expected a declaration.



ExpectedName

Expected a name.



ExpectedStructureMember

Expected a structure member.



ExpectedBlock

Expected a block.



ExpectedModuleBody

Expected a module body.



ExpectedFunctionBody

Expected a function body.



ExpectedEnumBody

Expected an enum body.



ExpectedEnumVariant

Expected an enum variant.



ExpectedIn

Expected the in keyword.



ExpectedFunctionParameters

Expected function parameters.



ExpectedThenOrBrace

Expected the then keyword or a block.



ExpectedColon

Expected a :



ExpectedCommaOrBrace

Expected a , or the end }.



ExpectedMatchBody

Expected a match body.



ExpectedPattern

Expected a pattern.



ExpectedPatternOr(Paired)

Expected a pattern or the end of the pattern match grouping.



ExpectedFatArrow

Expected a =>.



ExpectedCatchBlock

Expected a catch block.



InvalidAssignmentTarget

An assignment can only be done to a lookup (a.b = c) or an index (a[b] = c).



InvalidLabelTarget

The label specified can’t be found or belongs to an invalid target for this expression.



InvalidMapKeyPattern

Map keys must be literal values.