Enum muse_lang::compiler::syntax::PatternKind

source ·
pub enum PatternKind {
    Any(Option<Symbol>),
    AnyRemaining,
    Compare(PatternComparison),
    Literal(Literal),
    DestructureTuple(Box<Enclosed<Delimited<Ranged<PatternKind>>>>),
    DestructureMap(Box<Enclosed<Delimited<Ranged<EntryPattern>>>>),
    Or(Box<Ranged<PatternKind>>, Ranged<Token>, Box<Ranged<PatternKind>>),
}
The syntax components of a portion of a pattern match.

Variants



Any(Option<Symbol>)

Match any single expression, optionally assigning it a name.



AnyRemaining

Match any remaining expressions.



Compare(PatternComparison)

A comparison pattern.



Literal(Literal)

Match a literal value.



DestructureTuple(Box<Enclosed<Delimited<Ranged<PatternKind>>>>)

Match by destructuring the value as a tuple.



DestructureMap(Box<Enclosed<Delimited<Ranged<EntryPattern>>>>)

Match by destructuring the value as a map.



Or(Box<Ranged<PatternKind>>, Ranged<Token>, Box<Ranged<PatternKind>>)

Match by either one pattern or another pattern.