Struct muse_lang::compiler::syntax::Delimited

source ·
pub struct Delimited<T, Delimiter = Ranged<Token>> {
    pub first: Option<T>,
    pub remaining: Vec<(Delimiter, T)>,
}
A sequence of T, delimited by Delimiter.

Fields

first: Option<T>

The first entry in this sequence.

remaining: Vec<(Delimiter, T)>

The remaining delimiter and entries.

Implementations

source

impl<T, Delimiter> Delimited<T, Delimiter>

source

pub const fn single(value: T) -> Self

Returns a list from a single value.

source

pub const fn empty() -> Self

Returns an empty list.

source

pub const fn build(first: T) -> DelimitedBuilder<T, Delimiter>

Returns a builder with the first element provided.

source

pub const fn build_empty() -> DelimitedBuilder<T, Delimiter>

Returns an empty builder.

source

pub fn len(&self) -> usize

Returns the number of elements contained in this collection.

source

pub const fn is_empty(&self) -> bool

Returns true if this collection is empty.

source

pub fn iter(&self) -> DelimitedIter<'_, T, Delimiter>

Returns an iterator over the values in this list.

source

pub fn iter_mut(&mut self) -> DelimitedIterMut<'_, T, Delimiter>

Returns an iterator over exclusive references to values in this list.

source

pub fn last(&self) -> Option<&T>

Returns the last value in this list.