Struct muse_lang::compiler::syntax::DelimitedBuilder

source ·
pub struct DelimitedBuilder<T, Delimiter = Ranged<Token>> { /* private fields */ }
A builder that produces a Delimited list.

Implementations

source

impl<T, Delimiter> DelimitedBuilder<T, Delimiter>

source

pub const fn new(first: T) -> Self

Returns a builder that contains an initial element.

source

pub const fn empty() -> Self

Returns an empt builder.

source

pub fn finish(self) -> Delimited<T, Delimiter>

Returns the built collection.

source

pub fn set_delimiter(&mut self, delimiter: Delimiter)

Sets the delimiter to place between the next element and the current element.

Panics

This function must only be called once between invocations to push.

source

pub fn push(&mut self, value: T)

Pushes a new value to this list.

Panics

This function panics if a delimiter is expected and set_delimiter was not invoked before pushing a value.