pub struct RegexLiteral {
pub pattern: String,
pub expanded: bool,
pub ignore_case: bool,
pub unicode: bool,
pub dot_matches_all: bool,
pub multiline: bool,
}Expand description
A regular expression literal.
Fields
pattern: StringThe regular expression source.
expanded: boolIf true, whitespace is ignored by default.
See the documentation for ignore_whitespace for more information.
ignore_case: boolIf true, the regular expression will ignore uppercase/lowercase differences when matching.
unicode: boolWhen true, unicode mode is enabled for the regular expression.
dot_matches_all: boolWhen true, . matches all characters including new lines.
multiline: boolWhen true, the regular expression will operate in multiline mode.