Struct muse_lang::runtime::exception::Exception

source ·
pub struct Exception { /* private fields */ }
A thrown exception.

An exception contains two pieces of data:

Implementations

source

impl Exception

source

pub fn new(value: Value, vm: &mut VmContext<'_, '_>) -> Self

Returns a new exception with the current backtrace of the virtual machine.

source

pub const fn value(&self) -> Value

Returns the thrown value.

source

pub fn backtrace(&self) -> &[StackFrame]

Returns the list of recorded stack frames when this exception was thrown.

source

pub fn format( &self, sources: &Sources, context: &mut VmContext<'_, '_>, f: impl Write, ) -> Result

Displays this exception with its backtrace into f.