Struct muse_lang::runtime::list::List

source ·
pub struct List(/* private fields */);
A list of Values.

Implementations

source

impl List

source

pub const fn new() -> Self

Returns an empty list.

source

pub fn get_by_value(&self, index: &Value) -> Result<Value, Fault>

Returns the value at index.

Errors

Returns Fault::OutOfBounds if index cannot be converted to a usize or is out of bounds of this list.

source

pub fn get(&self, index: usize) -> Option<Value>

source

pub fn insert(&self, index: &Value, value: Value) -> Result<(), Fault>

Inserts value at index.

Errors

Returns Fault::OutOfBounds if index cannot be converted to a usize or is greater than the length of this list.

source

pub fn push(&self, value: Value) -> Result<(), Fault>

Pushes value to the end of the list.

source

pub fn set(&self, index: &Value, value: Value) -> Result<Value, Fault>

Replaces the value at index with value. Returns the previous value.

Errors

Returns Fault::OutOfBounds if index cannot be converted to a usize or is out of bounds of this list.

source

pub fn to_vec(&self) -> Vec<Value>

Converts this list into a Vec.