Struct muse_lang::runtime::map::Map

source ·
pub struct Map(/* private fields */);
A collection of key-value pairs.

Implementations

source

impl Map

source

pub const fn new() -> Self

Returns an empty map.

source

pub fn from_iterator( vm: &mut VmContext<'_, '_>, iter: impl IntoIterator<Item = (Value, Value)>, ) -> Self

Creates a map from an iterator of key-value pairs.

source

pub fn get( &self, vm: &mut VmContext<'_, '_>, key: &Value, ) -> Result<Option<Value>, Fault>

Returns the value contained for key, or None if this map does not contain key.

Errors

This function does not directly return any errors, but comparing values can result in runtime errors.

source

pub fn nth( &self, index: &Value, guard: &CollectionGuard<'_>, ) -> Result<Value, Fault>

Returns the value contained at index.

Errors

Returns Fault::OutOfBounds if index is out of bounds of this collection.

source

pub fn insert( &self, vm: &mut VmContext<'_, '_>, key: Value, value: Value, ) -> Result<Option<Value>, Fault>

Inserts a key-value pair into this map.

If an existing value is stored for key, it will be returned.

source

pub fn to_vec(&self) -> Vec<Field>

Returns this map as a vec of fields.