Enum muse_lang::runtime::value::Primitive

source ·
pub enum Primitive {
    Nil,
    Bool(bool),
    Int(i64),
    UInt(u64),
    Float(f64),
}
A primitive virtual machine value.

Variants



Nil

A value representing nothing.



Bool(bool)

A boolean value.



Int(i64)

A signed 64-bit integer.



UInt(u64)

An unsigned 64-bit integer.



Float(f64)

A double-preceision floating point number.

Implementations

source

impl Primitive

source

pub const fn is_nil(&self) -> bool

Returns true if this value is nil.

source

pub fn as_i64(&self) -> Option<i64>

Returns this value as an i64, if possible.

source

pub fn as_u64(&self) -> Option<u64>

Returns this value as an u64, if possible.

source

pub fn as_u32(&self) -> Option<u32>

Returns this value as an u32, if possible.

source

pub fn as_u16(&self) -> Option<u16>

Returns this value as an u16, if possible.

source

pub fn as_usize(&self) -> Option<usize>

Returns this value as an usize, if possible.

source

pub fn as_f64(&self) -> Option<f64>

Returns this value as an f64, if possible.

source

pub fn to_i64(&self) -> Option<i64>

Converts this value to an i64, if possible.

source

pub fn to_u64(&self) -> Option<u64>

Converts this value to an u64, if possible.

source

pub fn to_u32(&self) -> Option<u32>

Converts this value to an u32, if possible.

source

pub fn to_usize(&self) -> Option<usize>

Converts this value to an usize, if possible.

source

pub fn to_f64(&self) -> f64

Converts this value to an f64, if possible.

source

pub fn truthy(&self) -> bool

Returns true if this value should be considered true in a boolean expression.

source

pub fn add(&self, rhs: &Self) -> Result<Self, Fault>

Adds self to rhs.

source

pub fn sub(&self, rhs: &Self) -> Result<Self, Fault>

Subtracts rhs from self.

source

pub fn mul(&self, rhs: &Self) -> Result<Self, Fault>

Multiplies self by rhs.

source

pub fn pow(&self, exp: &Self) -> Result<Self, Fault>

Raises self to the rhs power.

source

pub fn div(&self, rhs: &Self) -> Result<Self, Fault>

Divides self by rhs.

source

pub fn idiv(&self, rhs: &Self) -> Result<Self, Fault>

Divides self by rhs, using whole numbers.

source

pub fn rem(&self, rhs: &Self) -> Result<Self, Fault>

Calcualtes the remainder of dividing self by rhs using whole numbers.

source

pub fn not(&self) -> Result<Self, Fault>

Returns the inverse of Self::truthy.

source

pub fn negate(&self) -> Self

Negates this value.

source

pub fn bitwise_not(&self) -> Result<Self, Fault>

Returns the bitwise not of this value.

source

pub fn bitwise_and(&self, rhs: &Self) -> Result<Self, Fault>

Returns the bitwise and of self and rhs.

source

pub fn bitwise_or(&self, rhs: &Self) -> Result<Self, Fault>

Returns the bitwise or of self and rhs.

source

pub fn bitwise_xor(&self, rhs: &Self) -> Result<Self, Fault>

Returns the bitwise xor of self and rhs.

source

pub fn shift_left(&self, rhs: &Self) -> Result<Self, Fault>

Returns the bitwise shift left of self by rhs.

source

pub fn shift_right(&self, rhs: &Self) -> Result<Self, Fault>

Returns the shift right of self by rhs.

source

pub fn to_string(&self) -> Result<SymbolRef, Fault>

Returns this value as a shared string reference.

source

pub fn hash_into(&self, hasher: &mut ValueHasher)

Hashes this value into hasher.

source

pub fn equals(&self, other: &Self) -> Result<bool, Fault>

Returns true if self and other are equivalent values.

source

pub fn total_cmp(&self, other: &Self) -> Result<Ordering, Fault>

Returns an ordering of self and other that takes into account both the type of data and the value itself.

source

pub fn take(&mut self) -> Primitive

Take the contents of this value, leaving nil behind.

source

pub fn format(&self, context: &mut VmContext<'_, '_>, f: impl Write) -> Result

Formats this value for display into f.