Enum muse_lang::runtime::value::RootedValue

source ·
pub enum RootedValue {
    Primitive(Primitive),
    Symbol(Symbol),
    Dynamic(AnyDynamicRoot),
}
A Muse virtual machine value that holds strong references.

Variants



Primitive(Primitive)



Symbol(Symbol)

A symbol.



Dynamic(AnyDynamicRoot)

A dynamically allocated, garbage collected type.

Implementations

source

impl RootedValue

source

pub const TRUE: Self = _

source

pub const FALSE: Self = _

source

pub const NIL: Self = _

source

pub const ZERO: Self = _

source

pub fn downgrade(&self) -> Value

Returns this value with weak references to any garbage collected data.

source

pub fn dynamic<'guard, T>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self
where T: DynamicValue + Trace,

Moves value into the virtual machine.

source

pub const fn is_nil(&self) -> bool

Returns true if this value is nil.

source

pub fn as_primitive(&self) -> Option<Primitive>

Returns this value as an i64, if possible.

source

pub fn as_i64(&self) -> Option<i64>

Returns this value as an i64, if possible.

source

pub fn as_u64(&self) -> Option<u64>

Returns this value as an u64, if possible.

source

pub fn as_u32(&self) -> Option<u32>

Returns this value as an u32, if possible.

source

pub fn as_u16(&self) -> Option<u16>

Returns this value as an u16, if possible.

source

pub fn as_usize(&self) -> Option<usize>

Returns this value as an usize, if possible.

source

pub fn as_f64(&self) -> Option<f64>

Returns this value as an f64, if possible.

source

pub fn to_i64(&self) -> Option<i64>

Converts this value to an i64, if possible.

source

pub fn to_u64(&self) -> Option<u64>

Converts this value to an u64, if possible.

source

pub fn to_u32(&self) -> Option<u32>

Converts this value to an u32, if possible.

source

pub fn to_usize(&self) -> Option<usize>

Converts this value to an usize, if possible.

source

pub fn to_f64(&self) -> Option<f64>

Converts this value to an f64, if possible.

source

pub fn as_symbol_ref(&self) -> Option<SymbolRef>

Returns this value as a SymbolRef, if possible.

source

pub fn as_symbol(&self) -> Option<&Symbol>

Returns this value as a Symbol, if possible.

source

pub fn as_any_dynamic(&self) -> Option<AnyDynamic>

Returns this value as an AnyDynamic, if possible.

source

pub fn as_dynamic<T>(&self) -> Option<Dynamic<T>>
where T: DynamicValue + Trace,

Returns this value as a Dynamic<T>, if this value contains a T.

source

pub fn as_rooted<T>(&self) -> Option<Rooted<T>>
where T: DynamicValue + Trace,

Returns this value as a Rooted<T>, if this value contains a T.

source

pub fn as_downcast_ref<T>(&self) -> Option<&T>
where T: DynamicValue + Trace,

Returns this value as a&T, if this value contains a T.

source

pub fn truthy(&self, vm: &mut VmContext<'_, '_>) -> bool

Returns true if this value should be considered true in a boolean expression.