Enum muse_lang::runtime::value::Value

source ·
pub enum Value {
    Primitive(Primitive),
    Symbol(SymbolRef),
    Dynamic(AnyDynamic),
}
A Muse virtual machine value.

Variants



Primitive(Primitive)



Symbol(SymbolRef)

A symbol.



Dynamic(AnyDynamic)

A dynamically allocated, garbage collected type.

Implementations

source

impl Value

source

pub const TRUE: Self = _

source

pub const FALSE: Self = _

source

pub const NIL: Self = _

source

pub const ZERO: Self = _

source

pub fn upgrade(&self, guard: &CollectionGuard<'_>) -> Option<RootedValue>

Returns this value with any garbage collected values upgraded to root references.

source

pub fn dynamic<'guard, T>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self
where T: DynamicValue + Trace,

Moves value into the virtual machine.

source

pub const fn is_nil(&self) -> bool

Returns true if this value is nil.

source

pub fn as_primitive(&self) -> Option<Primitive>

Returns this value as an i64, if possible.

source

pub fn as_i64(&self) -> Option<i64>

Returns this value as an i64, if possible.

source

pub fn as_u64(&self) -> Option<u64>

Returns this value as an u64, if possible.

source

pub fn as_u32(&self) -> Option<u32>

Returns this value as an u32, if possible.

source

pub fn as_u16(&self) -> Option<u16>

Returns this value as an u16, if possible.

source

pub fn as_usize(&self) -> Option<usize>

Returns this value as an usize, if possible.

source

pub fn as_f64(&self) -> Option<f64>

Returns this value as an f64, if possible.

source

pub fn to_i64(&self) -> Option<i64>

Converts this value to an i64, if possible.

source

pub fn to_u64(&self) -> Option<u64>

Converts this value to an u64, if possible.

source

pub fn to_u32(&self) -> Option<u32>

Converts this value to an u32, if possible.

source

pub fn to_usize(&self) -> Option<usize>

Converts this value to an usize, if possible.

source

pub fn to_f64(&self) -> Option<f64>

Converts this value to an f64, if possible.

source

pub fn as_symbol_ref(&self) -> Option<&SymbolRef>

Returns this value as a SymbolRef, if possible.

source

pub fn as_symbol(&self, guard: &CollectionGuard<'_>) -> Option<Symbol>

Returns this value as a Symbol, if possible.

source

pub fn as_any_dynamic(&self) -> Option<AnyDynamic>

Returns this value as an AnyDynamic, if possible.

source

pub fn as_dynamic<T>(&self) -> Option<Dynamic<T>>
where T: DynamicValue + Trace,

Returns this value as a Dynamic<T>, if this value contains a T.

source

pub fn as_rooted<T>(&self, guard: &CollectionGuard<'_>) -> Option<Rooted<T>>
where T: DynamicValue + Trace,

Returns this value as a Rooted<T>, if this value contains a T.

source

pub fn as_downcast_ref<'guard, T>( &self, guard: &'guard CollectionGuard<'_>, ) -> Option<&'guard T>
where T: DynamicValue + Trace,

Returns this value as a&T, if this value contains a T.

source

pub fn truthy(&self, vm: &mut VmContext<'_, '_>) -> bool

Returns true if this value should be considered true in a boolean expression.

source

pub fn call( &self, vm: &mut VmContext<'_, '_>, arity: impl Into<Arity>, ) -> Result<Value, Fault>

Invokes this value as a function.

source

pub fn invoke( &self, vm: &mut VmContext<'_, '_>, name: &SymbolRef, arity: impl Into<Arity>, ) -> Result<Value, Fault>

Invokes name on this value.

source

pub fn add( &self, vm: &mut VmContext<'_, '_>, rhs: &Self, ) -> Result<Value, Fault>

Adds self to rhs.

source

pub fn sub( &self, vm: &mut VmContext<'_, '_>, rhs: &Self, ) -> Result<Value, Fault>

Subtracts rhs from self.

source

pub fn mul( &self, vm: &mut VmContext<'_, '_>, rhs: &Self, ) -> Result<Value, Fault>

Multiplies self by rhs.

source

pub fn pow( &self, vm: &mut VmContext<'_, '_>, exp: &Self, ) -> Result<Value, Fault>

Raises self to the rhs power.

source

pub fn div( &self, vm: &mut VmContext<'_, '_>, rhs: &Self, ) -> Result<Value, Fault>

Divides self by rhs.

source

pub fn idiv( &self, vm: &mut VmContext<'_, '_>, rhs: &Self, ) -> Result<Value, Fault>

Divides self by rhs, using whole numbers.

source

pub fn rem( &self, vm: &mut VmContext<'_, '_>, rhs: &Self, ) -> Result<Value, Fault>

Calcualtes the remainder of dividing self by rhs using whole numbers.

source

pub fn not(&self, vm: &mut VmContext<'_, '_>) -> Result<Self, Fault>

Returns the inverse of Self::truthy.

source

pub fn negate(&self, vm: &mut VmContext<'_, '_>) -> Result<Self, Fault>

Negates this value.

source

pub fn bitwise_not(&self, vm: &mut VmContext<'_, '_>) -> Result<Self, Fault>

Returns the bitwise not of this value.

source

pub fn bitwise_and( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Self, Fault>

Returns the bitwise and of self and rhs.

source

pub fn bitwise_or( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Self, Fault>

Returns the bitwise or of self and rhs.

source

pub fn bitwise_xor( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Self, Fault>

Returns the bitwise xor of self and rhs.

source

pub fn shift_left( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Self, Fault>

Returns the bitwise shift left of self by rhs.

source

pub fn shift_right( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Self, Fault>

Returns the shift right of self by rhs.

source

pub fn to_string(&self, vm: &mut VmContext<'_, '_>) -> Result<SymbolRef, Fault>

Returns this value as a shared string reference.

source

pub fn map_str<R>( &self, vm: &mut VmContext<'_, '_>, map: impl FnOnce(&mut VmContext<'_, '_>, &str) -> R, ) -> Result<R, Fault>

Maps the contents of this value as a str, if possible.

source

pub fn hash_into(&self, vm: &mut VmContext<'_, '_>, hasher: &mut ValueHasher)

Hashes this value into hasher.

source

pub fn hash(&self, vm: &mut VmContext<'_, '_>) -> u64

Calculates the hash of this value.

source

pub fn equals( &self, vm: ContextOrGuard<'_, '_, '_>, other: &Self, ) -> Result<bool, Fault>

Returns true if self and other are equivalent values.

source

pub fn matches( &self, vm: &mut VmContext<'_, '_>, other: &Self, ) -> Result<bool, Fault>

Returns true if self matches other.

source

pub fn total_cmp( &self, vm: &mut VmContext<'_, '_>, other: &Self, ) -> Result<Ordering, Fault>

Returns an ordering of self and other that takes into account both the type of data and the value itself.

source

pub fn take(&mut self) -> Value

Take the contents of this value, leaving nil behind.

source

pub fn deep_clone(&self, guard: &CollectionGuard<'_>) -> Option<Value>

Perform a deep-clone on the contents of this value.

Not all types are able to be deeply cloned. Unsupported types will result in None.

source

pub fn format(&self, context: &mut VmContext<'_, '_>, f: impl Write) -> Result

Formats this value for display into f.