Struct muse_lang::runtime::value::AnyDynamic

source ·
pub struct AnyDynamic(/* private fields */);
A weak reference to a Rooted<T>.

Implementations

source

impl AnyDynamic

source

pub fn new<'guard, T>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self
where T: DynamicValue + Trace,

Returns value as a garbage collected value that can be used in Muse.

source

pub fn upgrade(&self, guard: &CollectionGuard<'_>) -> Option<AnyDynamicRoot>

Returns this dynamic upgraded to a root reference.

source

pub fn as_dynamic<T>(&self) -> Dynamic<T>
where T: DynamicValue + Trace,

Upgrades this reference to a Dynamic<T>.

This function does no type checking. If T is the incorrect type, trying to access the underyling data will return None/an error.

source

pub fn as_rooted<T>(&self, guard: &CollectionGuard<'_>) -> Option<Rooted<T>>
where T: DynamicValue + Trace,

Tries to upgrade this reference to a Rooted<T>.

This function can return None if:

  • T is not the correct type.
  • The value has been garbage collected.
source

pub fn downcast_ref<'guard, T>( &self, guard: &'guard CollectionGuard<'_>, ) -> Option<&'guard T>
where T: DynamicValue + Trace,

Tries to load a reference to this reference’s underlying data.

This function can return None if:

  • T is not the correct type.
  • The value has been garbage collected.
source

pub fn deep_clone(&self, guard: &CollectionGuard<'_>) -> Option<AnyDynamic>

Invokes deep_clone on the underlying type’s TypeVtable.

source

pub fn call( &self, vm: &mut VmContext<'_, '_>, arity: impl Into<Arity>, ) -> Result<Value, Fault>

Invokes call on the underlying type’s TypeVtable.

source

pub fn invoke( &self, vm: &mut VmContext<'_, '_>, symbol: &SymbolRef, arity: impl Into<Arity>, ) -> Result<Value, Fault>

Invokes invoke on the underlying type’s TypeVtable.

source

pub fn add( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Value, Fault>

Invokes add on the underlying type’s TypeVtable.

source

pub fn add_right( &self, vm: &mut VmContext<'_, '_>, lhs: &Value, ) -> Result<Value, Fault>

Invokes add_right on the underlying type’s TypeVtable.

source

pub fn sub( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Value, Fault>

Invokes sub on the underlying type’s TypeVtable.

source

pub fn sub_right( &self, vm: &mut VmContext<'_, '_>, lhs: &Value, ) -> Result<Value, Fault>

Invokes sub_right on the underlying type’s TypeVtable.

source

pub fn mul( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Value, Fault>

Invokes mul on the underlying type’s TypeVtable.

source

pub fn mul_right( &self, vm: &mut VmContext<'_, '_>, lhs: &Value, ) -> Result<Value, Fault>

Invokes mul_right on the underlying type’s TypeVtable.

source

pub fn div( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Value, Fault>

Invokes div on the underlying type’s TypeVtable.

source

pub fn div_right( &self, vm: &mut VmContext<'_, '_>, lhs: &Value, ) -> Result<Value, Fault>

Invokes div_right on the underlying type’s TypeVtable.

source

pub fn rem( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Value, Fault>

Invokes rem on the underlying type’s TypeVtable.

source

pub fn rem_right( &self, vm: &mut VmContext<'_, '_>, lhs: &Value, ) -> Result<Value, Fault>

Invokes rem_right on the underlying type’s TypeVtable.

source

pub fn idiv( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Value, Fault>

Invokes idiv on the underlying type’s TypeVtable.

source

pub fn idiv_right( &self, vm: &mut VmContext<'_, '_>, lhs: &Value, ) -> Result<Value, Fault>

Invokes idiv_right on the underlying type’s TypeVtable.

source

pub fn hash(&self, vm: &mut VmContext<'_, '_>, hasher: &mut ValueHasher)

Invokes hash on the underlying type’s TypeVtable.

source

pub fn bitwise_not(&self, vm: &mut VmContext<'_, '_>) -> Result<Value, Fault>

Invokes bitwise_not on the underlying type’s TypeVtable.

source

pub fn bitwise_and( &self, vm: &mut VmContext<'_, '_>, other: &Value, ) -> Result<Value, Fault>

Invokes bitwise_and on the underlying type’s TypeVtable.

source

pub fn bitwise_or( &self, vm: &mut VmContext<'_, '_>, other: &Value, ) -> Result<Value, Fault>

Invokes bitwise_or on the underlying type’s TypeVtable.

source

pub fn bitwise_xor( &self, vm: &mut VmContext<'_, '_>, other: &Value, ) -> Result<Value, Fault>

Invokes bitwise_xor on the underlying type’s TypeVtable.

source

pub fn shift_left( &self, vm: &mut VmContext<'_, '_>, amount: &Value, ) -> Result<Value, Fault>

Invokes shift_left on the underlying type’s TypeVtable.

source

pub fn shift_right( &self, vm: &mut VmContext<'_, '_>, amount: &Value, ) -> Result<Value, Fault>

Invokes shift_right on the underlying type’s TypeVtable.

source

pub fn negate(&self, vm: &mut VmContext<'_, '_>) -> Result<Value, Fault>

Invokes negate on the underlying type’s TypeVtable.

source

pub fn to_string(&self, vm: &mut VmContext<'_, '_>) -> Result<SymbolRef, Fault>

Invokes to_string on the underlying type’s TypeVtable.

source

pub fn truthy(&self, vm: &mut VmContext<'_, '_>) -> bool

Invokes truthy on the underlying type’s TypeVtable.

source

pub fn eq( &self, vm: ContextOrGuard<'_, '_, '_>, rhs: &Value, ) -> Result<bool, Fault>

Invokes eq on the underlying type’s TypeVtable.

source

pub fn matches( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<bool, Fault>

Invokes matches on the underlying type’s TypeVtable.

source

pub fn cmp( &self, vm: &mut VmContext<'_, '_>, rhs: &Value, ) -> Result<Ordering, Fault>

Invokes total_cmp on the underlying type’s TypeVtable.