Struct muse_lang::runtime::value::AnyDynamicRoot

source ·
pub struct AnyDynamicRoot(/* private fields */);
A strong reference to a Rooted<T>.

Implementations

source

impl AnyDynamicRoot

source

pub const fn downgrade(&self) -> AnyDynamic

Returns a weak reference to this dynamic.

source

pub fn new<'guard, T>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self
where T: DynamicValue + Trace,

Returns value as a garbage collected value that can be used in Muse.

source

pub fn as_dynamic<T>(&self) -> Dynamic<T>
where T: DynamicValue + Trace,

Upgrades this reference to a Dynamic<T>.

This function does no type checking. If T is the incorrect type, trying to access the underyling data will return None/an error.

source

pub fn as_rooted<T>(&self) -> Option<Rooted<T>>
where T: DynamicValue + Trace,

Tries to upgrade this reference to a Rooted<T>.

This function can return None if:

  • T is not the correct type.
  • The value has been garbage collected.
source

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DynamicValue + Trace,

Tries to load a reference to this reference’s underlying data.

This function can return None if:

  • T is not the correct type.
  • The value has been garbage collected.