Struct muse_lang::runtime::value::Dynamic

source ·
pub struct Dynamic<T: CustomType>(/* private fields */);
A weak reference to a Rooted<T>.

Implementations

source

impl<T> Dynamic<T>
where T: CustomType + Trace,

source

pub fn new<'guard>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self

Moves value into the garbage collector and returns a weak reference to it.

source

pub fn load<'guard>( &self, guard: &'guard CollectionGuard<'_>, ) -> Option<&'guard T>

Loads a reference to the underlying data, if it has not been collected.

source

pub fn try_load<'guard>( &self, guard: &'guard CollectionGuard<'_>, ) -> Result<&'guard T, ValueFreed>

Loads a reference to the underlying data, if it has not been collected.

source

pub fn as_rooted(&self, guard: &CollectionGuard<'_>) -> Option<Rooted<T>>

Loads a rooted reference to the underlying data, if it has not been collected.

source

pub const fn into_value(self) -> Value

Returns this dynamic as a Value.

source

pub const fn into_any_dynamic(self) -> AnyDynamic

Returns this reference with its type erased.