Struct muse_lang::runtime::value::Rooted

source ·
pub struct Rooted<T: CustomType + Trace>(/* private fields */);
A reference counted pointer to a garbage collected value.

Implementations

source

impl<T> Rooted<T>
where T: CustomType + Trace,

source

pub fn new<'guard>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self

Moves value into the garbage collector and returns a rooted reference to it.

source

pub const fn as_any_dynamic(&self) -> AnyDynamic

Returns a weak, typeless reference to this value.

source

pub const fn downgrade(&self) -> Dynamic<T>

Returns a weak reference to this value.

source

pub fn as_any_root(&self) -> AnyDynamicRoot

Returns this value as a typeless root reference.

source

pub fn into_any_root(self) -> AnyDynamicRoot

Returns this value as a typeless root reference.