Struct muse_lang::runtime::value::RustFunctionTable
source · pub struct RustFunctionTable<T> { /* private fields */ }Expand description
A table containing Rust-defined functions for various names and arities.
Implementations
sourceimpl<T> RustFunctionTable<T>where
T: CustomType + Trace,
impl<T> RustFunctionTable<T>where
T: CustomType + Trace,
sourcepub fn with_fn<F>(
self,
name: impl SymbolList,
arity: impl Into<Arity>,
func: F,
) -> Self
pub fn with_fn<F>( self, name: impl SymbolList, arity: impl Into<Arity>, func: F, ) -> Self
Adds a function with name and arity to this table, and returns self.q
sourcepub fn invoke(
&self,
vm: &mut VmContext<'_, '_>,
name: &SymbolRef,
arity: Arity,
this: &Rooted<T>,
) -> Result<Value, Fault>
pub fn invoke( &self, vm: &mut VmContext<'_, '_>, name: &SymbolRef, arity: Arity, this: &Rooted<T>, ) -> Result<Value, Fault>
Invokes a function named name with arity arguments.
Errors
Fault::UnknownSymbol: Returned if this table has no functions with the given name.Fault::IncorrectNumberOfArguments: Returned if no functions with the given name accept the given number of arguments.