Enum muse_lang::vm::bitcode::Op

source ·
pub enum Op {
    Return,
    Label(Label),
    LoadModule {
        module: BitcodeModule,
        dest: OpDestination,
    },
    Declare {
        name: Symbol,
        mutable: bool,
        access: Access,
        value: ValueOrSource,
        dest: OpDestination,
    },
    Unary {
        op: ValueOrSource,
        dest: OpDestination,
        kind: UnaryKind,
    },
    BinOp {
        op1: ValueOrSource,
        op2: ValueOrSource,
        dest: OpDestination,
        kind: BinaryKind,
    },
    Call {
        name: ValueOrSource,
        arity: ValueOrSource,
    },
    Invoke {
        target: ValueOrSource,
        name: Symbol,
        arity: ValueOrSource,
    },
    Throw(FaultKind),
}
A virtual machine operation.

Variants



Return

Return from the current function.



Label(Label)

Assign this label to the next instruction.



LoadModule

Load module, storing a reference into dest.

Fields

module: BitcodeModule

The module to load.

dest: OpDestination

The location to store the loaded module.



Declare

Declare name with value, storing a copy of the value in dest.

Fields

name: Symbol

The name of the declaration.

mutable: bool

If true, the value will be able to be updated with an assignment.

access: Access

The access level to allow for this declaration.

value: ValueOrSource

The initial value of the declaration.

dest: OpDestination

The destination to store a copy of value.



Unary

An operation with one argument that stores its result in dest.

Fields

op: ValueOrSource

The value to operate on.

dest: OpDestination

The destination for the result.

kind: UnaryKind

The operation kind.



BinOp

An operation with two arguments that stores its result in dest.

Fields

op1: ValueOrSource

The first value to operate on.

op2: ValueOrSource

The second value to operate on.

dest: OpDestination

The destination for the result.

kind: BinaryKind

The operation kind.



Call

Invoke name as a function with arity number of arguments provided.

Fields

name: ValueOrSource

The name of the function.

arity: ValueOrSource

The number of arguments provided to this invocation.



Invoke

Invoke name on target with arity number of arguments provided.

Fields

target: ValueOrSource

The target to invoke the function on.

name: Symbol

The name of the function.

arity: ValueOrSource

The number of arguments provided to this invocation.



Throw(FaultKind)

Throw an exception.