Struct muse_lang::vm::bitcode::BitcodeFunction
source · pub struct BitcodeFunction { /* private fields */ }Expand description
An IR Function.
Implementations
sourceimpl BitcodeFunction
impl BitcodeFunction
sourcepub fn new(name: impl IntoOptionSymbol) -> Self
pub fn new(name: impl IntoOptionSymbol) -> Self
Returns a new function with name.
sourcepub fn from_function(bit: &Function, guard: &CollectionGuard<'_>) -> Self
pub fn from_function(bit: &Function, guard: &CollectionGuard<'_>) -> Self
Returns a function from the contents of bit.
sourcepub fn insert_arity(
&mut self,
arity: impl Into<Arity>,
body: impl Into<BitcodeBlock>,
)
pub fn insert_arity( &mut self, arity: impl Into<Arity>, body: impl Into<BitcodeBlock>, )
Inserts a new function body to be executed when arity number of
arguments are provided.
sourcepub fn insert_variable_arity(
&mut self,
arity: impl Into<Arity>,
body: impl Into<BitcodeBlock>,
)
pub fn insert_variable_arity( &mut self, arity: impl Into<Arity>, body: impl Into<BitcodeBlock>, )
Inserts a new function body to be executed when arity or more number
of arguments are provided.
sourcepub fn when(
self,
arity: impl Into<Arity>,
body: impl Into<BitcodeBlock>,
) -> Self
pub fn when( self, arity: impl Into<Arity>, body: impl Into<BitcodeBlock>, ) -> Self
Adds a new function body to be executed when arity number of arguments
are provided, and returns self.
sourcepub fn to_function(&self, guard: &CollectionGuard<'_>) -> Function
pub fn to_function(&self, guard: &CollectionGuard<'_>) -> Function
Loads this function for execution in the virtual machine.