Enum muse_lang::vm::ExecutionError

source ·
pub enum ExecutionError {
    NoBudget,
    Waiting,
    Timeout,
    Exception(Value),
}
An error that arises from executing Muse code.

Variants



NoBudget

The budget for the virtual machine has been exhausted.



Waiting

The virtual machine is waiting for an async task.



Timeout

Execution did not complete before a timeout occurred.



Exception(Value)

A thrown exception was not handled.

Implementations

source

impl ExecutionError

source

pub fn as_value(&self) -> Value

Returns this error as a Value.