pub struct Function { /* private fields */ }Expand description
A Muse function ready for execution.
Implementations
sourceimpl Function
impl Function
sourcepub fn new(name: impl IntoOptionSymbol) -> Self
pub fn new(name: impl IntoOptionSymbol) -> Self
Returns a function with the given name and no bodies.
sourcepub fn insert_arity(&mut self, arity: impl Into<Arity>, body: Code)
pub fn insert_arity(&mut self, arity: impl Into<Arity>, body: Code)
Inserts body to be executed when this function is invoked with arity
number of arguments.