Struct muse_lang::vm::VmState

source ·
pub struct VmState { /* private fields */ }
The state of a Vm.

Virtual machines are garbage collected types, which requires interior mutability so that the garbage collector can trace what every allocated virtual machine is currently referencing.

Implementations

source

impl VmState

source

pub fn set_steps_per_charge(&mut self, steps: u16)

Sets the number of virtual machine steps to take per budget being charged.

This also affects how often the virtual machine checks if it should yield to the garbage collector.

source

pub const fn registers(&self) -> &[Value; 256]

Returns a slice of the registers.

source

pub fn registers_mut(&mut self) -> &mut [Value; 256]

Returns exclusive access to the registers.

source

pub fn current_module(&self) -> ModuleId

Returns the id of the module that owns the code currently executing.

source

pub fn root_module(&self) -> Dynamic<Module>

Returns the root module for this virtual machine.