Struct muse_lang::compiler::syntax::TrackedSource
source · pub struct TrackedSource {
pub name: String,
pub source: String,
/* private fields */
}Expand description
An entry in a Sources collection.
Fields
name: StringThe name of this source.
source: StringThe text of this source.
Implementations
sourceimpl TrackedSource
impl TrackedSource
sourcepub fn offset_to_line(&self, offset: usize) -> (usize, usize)
pub fn offset_to_line(&self, offset: usize) -> (usize, usize)
Returns the line number and column of offset in this source.
If offset is out of bounds, this function returns the last line and
column relative to that line’s start.