pub struct List(/* private fields */);Expand description
A list of Values.
Implementations
sourceimpl List
impl List
sourcepub fn get_by_value(&self, index: &Value) -> Result<Value, Fault>
pub fn get_by_value(&self, index: &Value) -> Result<Value, Fault>
Returns the value at index.
Errors
Returns Fault::OutOfBounds if index cannot be converted to a
usize or is out of bounds of this list.
pub fn get(&self, index: usize) -> Option<Value>
sourcepub fn insert(&self, index: &Value, value: Value) -> Result<(), Fault>
pub fn insert(&self, index: &Value, value: Value) -> Result<(), Fault>
Inserts value at index.
Errors
Returns Fault::OutOfBounds if index cannot be converted to a
usize or is greater than the length of this list.