pub struct SymbolRef(/* private fields */);Expand description
A garbage-collected weak reference to a Symbol.
Implementations
sourceimpl SymbolRef
impl SymbolRef
sourcepub fn load<'guard>(
&self,
guard: &'guard CollectionGuard<'_>,
) -> Option<&'guard str>
pub fn load<'guard>( &self, guard: &'guard CollectionGuard<'_>, ) -> Option<&'guard str>
Loads the underlying string value of this symbol.
Returns None if the underlying symbol has been freed by the garbage
collector.
sourcepub fn try_load<'guard>(
&self,
guard: &'guard CollectionGuard<'_>,
) -> Result<&'guard str, ValueFreed>
pub fn try_load<'guard>( &self, guard: &'guard CollectionGuard<'_>, ) -> Result<&'guard str, ValueFreed>
Tries to loads the underlying string value of this symbol.
Errors
Returns ValueFreed if the underlying symbol has been freed by the
garbage collector.
sourcepub fn upgrade(&self, guard: &CollectionGuard<'_>) -> Option<Symbol>
pub fn upgrade(&self, guard: &CollectionGuard<'_>) -> Option<Symbol>
Upgrades this weak reference to a reference-counted Symbol.
Returns None if the underlying symbol has been freed by the garbage
collector.
sourcepub fn try_upgrade(
&self,
guard: &CollectionGuard<'_>,
) -> Result<Symbol, ValueFreed>
pub fn try_upgrade( &self, guard: &CollectionGuard<'_>, ) -> Result<Symbol, ValueFreed>
Tries to upgrade this weak reference to a reference-counted Symbol.
Errors
Returns ValueFreed if the underlying symbol has been freed by the
garbage collector.