Enum muse_lang::runtime::value::RootedValue
source · pub enum RootedValue {
Primitive(Primitive),
Symbol(Symbol),
Dynamic(AnyDynamicRoot),
}Expand description
A Muse virtual machine value that holds strong references.
Variants
Primitive(Primitive)
Symbol(Symbol)
A symbol.
Dynamic(AnyDynamicRoot)
A dynamically allocated, garbage collected type.
Implementations
sourceimpl RootedValue
impl RootedValue
pub const TRUE: Self = _
pub const FALSE: Self = _
pub const NIL: Self = _
pub const ZERO: Self = _
sourcepub fn downgrade(&self) -> Value
pub fn downgrade(&self) -> Value
Returns this value with weak references to any garbage collected data.
sourcepub fn dynamic<'guard, T>(
value: T,
guard: &impl AsRef<CollectionGuard<'guard>>,
) -> Selfwhere
T: DynamicValue + Trace,
pub fn dynamic<'guard, T>(
value: T,
guard: &impl AsRef<CollectionGuard<'guard>>,
) -> Selfwhere
T: DynamicValue + Trace,
Moves value into the virtual machine.
sourcepub fn as_primitive(&self) -> Option<Primitive>
pub fn as_primitive(&self) -> Option<Primitive>
Returns this value as an i64, if possible.
sourcepub fn as_symbol_ref(&self) -> Option<SymbolRef>
pub fn as_symbol_ref(&self) -> Option<SymbolRef>
Returns this value as a SymbolRef, if possible.
sourcepub fn as_any_dynamic(&self) -> Option<AnyDynamic>
pub fn as_any_dynamic(&self) -> Option<AnyDynamic>
Returns this value as an AnyDynamic, if possible.
sourcepub fn as_dynamic<T>(&self) -> Option<Dynamic<T>>where
T: DynamicValue + Trace,
pub fn as_dynamic<T>(&self) -> Option<Dynamic<T>>where
T: DynamicValue + Trace,
Returns this value as a Dynamic<T>, if this value contains a T.
sourcepub fn as_rooted<T>(&self) -> Option<Rooted<T>>where
T: DynamicValue + Trace,
pub fn as_rooted<T>(&self) -> Option<Rooted<T>>where
T: DynamicValue + Trace,
Returns this value as a Rooted<T>, if this value contains a T.
sourcepub fn as_downcast_ref<T>(&self) -> Option<&T>where
T: DynamicValue + Trace,
pub fn as_downcast_ref<T>(&self) -> Option<&T>where
T: DynamicValue + Trace,
Returns this value as a&T, if this value contains a T.