Struct muse_lang::runtime::value::AnyDynamicRoot
source · pub struct AnyDynamicRoot(/* private fields */);Expand description
A strong reference to a Rooted<T>.
Implementations
sourceimpl AnyDynamicRoot
impl AnyDynamicRoot
sourcepub const fn downgrade(&self) -> AnyDynamic
pub const fn downgrade(&self) -> AnyDynamic
Returns a weak reference to this dynamic.
sourcepub fn new<'guard, T>(
value: T,
guard: &impl AsRef<CollectionGuard<'guard>>,
) -> Selfwhere
T: DynamicValue + Trace,
pub fn new<'guard, T>(
value: T,
guard: &impl AsRef<CollectionGuard<'guard>>,
) -> Selfwhere
T: DynamicValue + Trace,
Returns value as a garbage collected value that can be used in Muse.
sourcepub fn as_dynamic<T>(&self) -> Dynamic<T>where
T: DynamicValue + Trace,
pub fn as_dynamic<T>(&self) -> Dynamic<T>where
T: DynamicValue + Trace,
Upgrades this reference to a Dynamic<T>.
This function does no type checking. If T is the incorrect type,
trying to access the underyling data will return None/an error.
sourcepub fn as_rooted<T>(&self) -> Option<Rooted<T>>where
T: DynamicValue + Trace,
pub fn as_rooted<T>(&self) -> Option<Rooted<T>>where
T: DynamicValue + Trace,
Tries to upgrade this reference to a Rooted<T>.
This function can return None if:
Tis not the correct type.- The value has been garbage collected.
sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DynamicValue + Trace,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DynamicValue + Trace,
Tries to load a reference to this reference’s underlying data.
This function can return None if:
Tis not the correct type.- The value has been garbage collected.