pub struct Dynamic<T: CustomType>(/* private fields */);Expand description
A weak reference to a Rooted<T>.
Implementations
sourceimpl<T> Dynamic<T>where
T: CustomType + Trace,
impl<T> Dynamic<T>where
T: CustomType + Trace,
sourcepub fn new<'guard>(
value: T,
guard: &impl AsRef<CollectionGuard<'guard>>,
) -> Self
pub fn new<'guard>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self
Moves value into the garbage collector and returns a weak reference to
it.
sourcepub fn load<'guard>(
&self,
guard: &'guard CollectionGuard<'_>,
) -> Option<&'guard T>
pub fn load<'guard>( &self, guard: &'guard CollectionGuard<'_>, ) -> Option<&'guard T>
Loads a reference to the underlying data, if it has not been collected.
sourcepub fn try_load<'guard>(
&self,
guard: &'guard CollectionGuard<'_>,
) -> Result<&'guard T, ValueFreed>
pub fn try_load<'guard>( &self, guard: &'guard CollectionGuard<'_>, ) -> Result<&'guard T, ValueFreed>
Loads a reference to the underlying data, if it has not been collected.
sourcepub fn as_rooted(&self, guard: &CollectionGuard<'_>) -> Option<Rooted<T>>
pub fn as_rooted(&self, guard: &CollectionGuard<'_>) -> Option<Rooted<T>>
Loads a rooted reference to the underlying data, if it has not been collected.
sourcepub const fn into_value(self) -> Value
pub const fn into_value(self) -> Value
Returns this dynamic as a Value.
sourcepub const fn into_any_dynamic(self) -> AnyDynamic
pub const fn into_any_dynamic(self) -> AnyDynamic
Returns this reference with its type erased.