pub struct Rooted<T: CustomType + Trace>(/* private fields */);Expand description
A reference counted pointer to a garbage collected value.
Implementations
sourceimpl<T> Rooted<T>where
T: CustomType + Trace,
impl<T> Rooted<T>where
T: CustomType + Trace,
sourcepub fn new<'guard>(
value: T,
guard: &impl AsRef<CollectionGuard<'guard>>,
) -> Self
pub fn new<'guard>( value: T, guard: &impl AsRef<CollectionGuard<'guard>>, ) -> Self
Moves value into the garbage collector and returns a rooted reference
to it.
sourcepub const fn as_any_dynamic(&self) -> AnyDynamic
pub const fn as_any_dynamic(&self) -> AnyDynamic
Returns a weak, typeless reference to this value.
sourcepub fn as_any_root(&self) -> AnyDynamicRoot
pub fn as_any_root(&self) -> AnyDynamicRoot
Returns this value as a typeless root reference.
sourcepub fn into_any_root(self) -> AnyDynamicRoot
pub fn into_any_root(self) -> AnyDynamicRoot
Returns this value as a typeless root reference.